Index: cpukit/ChangeLog
===================================================================
--- cpukit/ChangeLog	(revision 7d1714545b80f8302dd1714333645d17797bf675)
+++ cpukit/ChangeLog	(revision 91b8fb9e9aae067834e702370b311c69a05e1df9)
@@ -1,2 +1,10 @@
+2008-01-31	Joel Sherrill <joel.sherrill@OARcorp.com>
+
+	* score/include/rtems/score/object.h, score/src/objectgetinfo.c,
+	rtems/include/rtems/rtems/object.h,
+	rtems/src/rtemsobjectgetapiclassname.c,
+	rtems/src/rtemsobjectgetclassinfo.c: class is a C++ keyword and
+	cannot be used as a parameter.
+
 2008-01-30	Joel Sherrill <joel.sherrill@OARcorp.com>
 
Index: cpukit/rtems/src/rtemsobjectgetapiclassname.c
===================================================================
--- cpukit/rtems/src/rtemsobjectgetapiclassname.c	(revision 7d1714545b80f8302dd1714333645d17797bf675)
+++ cpukit/rtems/src/rtemsobjectgetapiclassname.c	(revision 91b8fb9e9aae067834e702370b311c69a05e1df9)
@@ -71,6 +71,6 @@
 
 const char *rtems_object_get_api_class_name(
-  uint32_t api, 
-  uint32_t class
+  uint32_t the_api, 
+  uint32_t the_class
 )
 {
@@ -78,5 +78,5 @@
   const rtems_assoc_t *class_assoc;
   
-  switch (api) {
+  switch (the_api) {
     case OBJECTS_INTERNAL_API:
       api_assoc = rtems_object_api_internal_assoc;
@@ -98,5 +98,5 @@
       return "BAD API";
   }
-  class_assoc = rtems_assoc_ptr_by_local( api_assoc, class );
+  class_assoc = rtems_assoc_ptr_by_local( api_assoc, the_class );
   if ( class_assoc )
     return class_assoc->name;
Index: cpukit/rtems/src/rtemsobjectgetclassinfo.c
===================================================================
--- cpukit/rtems/src/rtemsobjectgetclassinfo.c	(revision 7d1714545b80f8302dd1714333645d17797bf675)
+++ cpukit/rtems/src/rtemsobjectgetclassinfo.c	(revision 91b8fb9e9aae067834e702370b311c69a05e1df9)
@@ -25,6 +25,6 @@
 
 rtems_status_code rtems_object_get_class_information(
-  uint32_t                            api,
-  uint32_t                            class,
+  uint32_t                            the_api,
+  uint32_t                            the_class,
   rtems_object_api_class_information *info
 )
@@ -40,5 +40,5 @@
     return RTEMS_INVALID_ADDRESS;
 
-  obj_info = _Objects_Get_information( api, class );
+  obj_info = _Objects_Get_information( the_api, the_class );
   if ( !obj_info )
     return RTEMS_INVALID_NUMBER;
Index: cpukit/score/src/objectgetinfo.c
===================================================================
--- cpukit/score/src/objectgetinfo.c	(revision 7d1714545b80f8302dd1714333645d17797bf675)
+++ cpukit/score/src/objectgetinfo.c	(revision 91b8fb9e9aae067834e702370b311c69a05e1df9)
@@ -20,17 +20,17 @@
 
 Objects_Information *_Objects_Get_information(
-  Objects_APIs   api,
-  uint32_t       class
+  Objects_APIs   the_api,
+  uint32_t       the_class
 )
 {
   Objects_Information *info;
 
-  if ( !_Objects_Is_api_valid( api ) )
+  if ( !_Objects_Is_api_valid( the_api ) )
     return NULL;
 
-  if ( !class || class > _Objects_API_maximum_class(api) )
+  if ( !the_class || the_class > _Objects_API_maximum_class(the_api) )
     return NULL;
 
-  info = _Objects_Information_table[ api ][ class ];
+  info = _Objects_Information_table[ the_api ][ the_class ];
   if ( !info )
     return NULL;

Index: cpukit/rtems/include/rtems/rtems/object.h
===================================================================
--- cpukit/rtems/include/rtems/rtems/object.h	(revision 7d1714545b80f8302dd1714333645d17797bf675)
+++ cpukit/rtems/include/rtems/rtems/object.h	(revision 91b8fb9e9aae067834e702370b311c69a05e1df9)
@@ -21,4 +21,5 @@
 #endif
 
+#include <stdint.h>
 #include <rtems/score/object.h>
 #include <rtems/rtems/status.h>
@@ -288,6 +289,6 @@
  *  @a class from the specified @a api.
  *
  *  @param[in] api is the API for the class
  *  @param[in] class is the class to obtain the name of
  *
  *  @return If successful, this method returns the name of
@@ -296,6 +297,6 @@
  */
 const char *rtems_object_get_api_class_name(
-  uint32_t api, 
-  uint32_t class
+  uint32_t the_api, 
+  uint32_t the_class
 );
 
@@ -304,8 +305,8 @@
  *
  *  This method returns a string containing the name of the
  *  @a class from the specified @a api.
  *
  *  @param[in] api is the API for the class
  *  @param[in] class is the class to obtain information about
  *  @param[in] info points to the information structure to fill in
  *
@@ -316,6 +317,6 @@
  */
 rtems_status_code rtems_object_get_class_information(
-  uint32_t                            api,
-  uint32_t                            class,
+  uint32_t                            the_api,
+  uint32_t                            the_class,
   rtems_object_api_class_information *info
 );
@@ -288,6 +289,6 @@
  *  @a class from the specified @a api.
  *
- *  @param[in] api is the API for the class
- *  @param[in] class is the class to obtain the name of
+ *  @param[in] the_api is the API for the class
+ *  @param[in] the_class is the class to obtain the name of
  *
  *  @return If successful, this method returns the name of
@@ -304,8 +305,8 @@
  *
  *  This method returns a string containing the name of the
- *  @a class from the specified @a api.
- *
- *  @param[in] api is the API for the class
- *  @param[in] class is the class to obtain information about
+ *  @a the_class from the specified @a api.
+ *
+ *  @param[in] the_api is the API for the class
+ *  @param[in] the_class is the class to obtain information about
  *  @param[in] info points to the information structure to fill in
  *
Index: cpukit/score/include/rtems/score/object.h
===================================================================
--- cpukit/score/include/rtems/score/object.h	(revision 7d1714545b80f8302dd1714333645d17797bf675)
+++ cpukit/score/include/rtems/score/object.h	(revision 91b8fb9e9aae067834e702370b311c69a05e1df9)
@@ -804,6 +804,6 @@
  *  the existence of any objects created by the API.
  *
  *  @param[in] api indicates the API for the information we want
  *  @param[in] class indicates the Class for the information we want
  *
  *  @return This method returns a pointer to the Object Information Table
@@ -811,6 +811,6 @@
  */
 Objects_Information *_Objects_Get_information(
-  Objects_APIs   api,
-  uint32_t       class
+  Objects_APIs   the_api,
+  uint32_t       the_class
 );
 
@@ -804,6 +804,6 @@
  *  the existence of any objects created by the API.
  *
- *  @param[in] api indicates the API for the information we want
- *  @param[in] class indicates the Class for the information we want
+ *  @param[in] the_api indicates the API for the information we want
+ *  @param[in] the_class indicates the Class for the information we want
  *
  *  @return This method returns a pointer to the Object Information Table